@@ -2,7 +2,7 @@
 This module contains the default values for distkv configuration.
 """
 
-from .util import attrdict, combine_dict
+from .util import attrdict, combine_dict, NotGiven
 from .ext import list_ext, load_ext
 
 __all__ = ["PORT", "CFG"]
@@ -20,18 +20,18 @@ CFG = attrdict(
         "loggers": {"asyncserf": {"level": "INFO"}},
         "root": {"handlers": ["stderr"], "level": "INFO"},
         "handlers": {
-#           "logfile": {
-#               "class": "logging.FileHandler",
-#               "filename": "test.log",
-#               "level": "DEBUG",
-#               "formatter": "std",
-#           },
+            #           "logfile": {
+            #               "class": "logging.FileHandler",
+            #               "filename": "test.log",
+            #               "level": "DEBUG",
+            #               "formatter": "std",
+            #           },
             "stderr": {
                 "class": "logging.StreamHandler",
                 "level": "DEBUG",
                 "formatter": "std",
                 "stream": "ext://sys.stderr",
-            },
+            }
         },
         "formatters": {
             "std": {
@@ -66,20 +66,17 @@ CFG = attrdict(
             cycle=10, nodes=-1, splits=5  # required for Runner
         ),
         sub=attrdict(  # tags for various runner modes
-            group="any",
-            single="at",
-            all="all",
+            group="any", single="at", all="all"
         ),
     ),
     server=attrdict(
         # server-side configuration
-        backend="serf",
+        backend=NotGiven,  # must be specified
         serf=attrdict(
             # how to connect to Serf
             host="localhost",
             port=7373,
         ),
-
         root=(":distkv",),  # event message name prefix. Should start with a colon.
         paranoia=False,  # typecheck server-to-server updates?
         # which addresses/ports to accept DistKV connections on
@@ -101,5 +98,5 @@ CFG = attrdict(
     },
 )
 
-for n,f in list_ext('config'):
-    CFG[n] = combine_dict(load_ext(n,"config","CFG"), CFG.get(n,{}), cls=attrdict)
+for n, f in list_ext("config"):
+    CFG[n] = combine_dict(load_ext(n, "config", "CFG"), CFG.get(n, {}), cls=attrdict)
