@@ -106,6 +106,20 @@ class ErrorSubEntry(AttrClientEntry):
         logger.warning("Unknown entry type at %r: %s", self._path, name)
         return ClientEntry
 
+    def __repr__(self):
+        return "‹%s %s %d›" % (
+            self.__class__.__name__,
+            self._path[-3:],
+            getattr(self, "tock", -1),
+        )
+
+    async def set_value(self, value):
+        await super().set_value(value)
+        if value is NotGiven:
+            p = self.parent
+            if p is not None:
+                await self.parent.check_move()
+
 
 class ErrorEntry(AttrClientEntry):
     """
@@ -125,7 +139,12 @@ class ErrorEntry(AttrClientEntry):
         self.node, self.tock = self.subpath[-2:]
 
     def __repr__(self):
-        return "<%s: %s %s: %s>" % (self.__class__.__name__, "/".join(str(x) for x in self.subpath), self.subsystem, " ".join(str(x) for x in self.path))
+        return "<%s: %s %s: %s>" % (
+            self.__class__.__name__,
+            "/".join(str(x) for x in self.subpath),
+            self.subsystem,
+            " ".join(str(x) for x in self.path),
+        )
 
     @classmethod
     def child_type(cls, name):
@@ -137,6 +156,11 @@ class ErrorEntry(AttrClientEntry):
             self = self._real_entry  # pylint: disable=self-cls-assignment
         return self
 
+    async def check_move(self):
+        dest = self.real_entry
+        if dest is not self:
+            await self.root.add_clean(self)
+
     async def resolve(self):
         """
         Record that this error has been resolved.
@@ -160,12 +184,12 @@ class ErrorEntry(AttrClientEntry):
             res = self.allocate(node)
         res.seen = time()
         res.tock = await self.root.client.get_tock()
-        res.comment=comment or repr(exc)
-        
+        res.comment = comment or repr(exc)
+
         if exc is not None:
             t = traceback.format_exception(type(exc), exc, exc.__traceback__)
             if len(t) > 40:
-                t = t[:10]+["…\n"]+t[:30]
+                t = t[:10] + ["…\n"] + t[:30]
             res.trace = "".join(t)
         if message is not None:
             res.message = message
@@ -191,11 +215,11 @@ class ErrorEntry(AttrClientEntry):
             await res.save()
         except TypeError:
             for k in res.ATTRS:
-                v = getattr(res,k,None)
+                v = getattr(res, k, None)
                 try:
                     packer(v)
                 except TypeError:
-                    setattr(res,k,repr(v))
+                    setattr(res, k, repr(v))
             await res.save()
 
     async def add_comment(self, node, comment, data):
@@ -212,7 +236,7 @@ class ErrorEntry(AttrClientEntry):
         logger.info("Comment %s: %s", node, comment)
         await self.root.client.set(*self._path, chain=self.chain, value=res)
 
-    async def delete(self):
+    async def delete(self):  # pylint: disable=signature-differs,arguments-differ
         """
         Delete myself from storage.
 
@@ -233,44 +257,53 @@ class ErrorEntry(AttrClientEntry):
         """
 
         dest = self.real_entry
+        # logger.warning("DEL 1 %r %r",self,dest)
         assert dest is not self, self
         kid = self.get(self.root.name)
         if kid is not None:
             dkid = dest.get(self.root.name)
+            # logger.warning("DEL 2 %r %r %r %r",self,dest,kid,dkid)
             if dkid is None:
                 val = kid.get_value()
                 dkid = dest.allocate(self.root.name)
                 await dkid.set_value(val)
                 await dkid.save()
-            elif dkid.tock > kid.tock:
+            elif getattr(dkid, "tock", 0) < getattr(kid, "tock", 0):
                 await dkid.set_value(val)
                 await dkid.save()
+            # logger.warning("DEL 3 %r %r %r",self,dest,dkid)
             await kid.delete()
         if not len(self):
+            # logger.warning("DEL 4 %r",self)
             await self.delete()
+        # logger.warning("DEL 5 %r",self)
 
-    async def set_value(self, val):
+    async def set_value(self, value):
         """Overridden: set_value
-        
+
         Stores a pointer to the error in the root and keeps the records unique
         """
 
         await self.root._pop(self)
-        if val is NotGiven:
+        if value is NotGiven:
             if self.value is NotGiven:
                 return
-            keep = await self.root.get_error_record(self.subsystem, *self.path, create=False)
+            keep = await self.root.get_error_record(
+                self.subsystem, *self.path, create=False
+            )
             if keep is not None:
                 self._real_entry = keep.real_entry
                 await self.move_to_real()
-            await super().set_value(val)
+            await super().set_value(value)
             return
 
-        await super().set_value(val)
+        await super().set_value(value)
 
         drop, keep = await self.root._unique(self)
+        # logger.debug("UNIQ %r %r %r %s/%s",self,drop,keep,
+        # "x" if drop is None else drop.subpath[0],self.root.name)
         if drop is not None:
-            #self.root._dropped(drop)
+            # self.root._dropped(drop)
             drop._real_entry = keep
 
             if drop.subpath[0] == self.root.name:
@@ -320,11 +353,18 @@ class ErrorRoot(ClientRoot):
         self._active = defaultdict(dict)  # subsystem > path > Entry
         self._done = defaultdict(WeakValueDictionary)  # subsystem > path > Entry
         self._latest = Cache(100)
+        self._to_clean = set()
 
     @classmethod
     def child_type(cls, name):
         return ErrorStep
 
+    async def add_clean(self, entry):
+        # self._to_clean.add(entry)
+        pass
+        # TODO run cleanup code that consolidates these errors when we get a TagMessage
+        # TODO use a weakset
+
     def all_errors(self, subsystem=None):
         """
         Iterate over all active errors, either a single subsystem or all of
@@ -343,8 +383,9 @@ class ErrorRoot(ClientRoot):
     async def get_error_record(self, subsystem, *path, create=True):
         """Retrieve or generate an error record for a particular subsystem
         and path.
-        
-        If ``create`` is set, the record may be incomplete and must be filled and stored by the caller.
+
+        If ``create`` is set, the record may be incomplete and
+        must be filled and stored by the caller.
         """
 
         err = self._active[subsystem].get(path, None)
@@ -386,13 +427,13 @@ class ErrorRoot(ClientRoot):
         elif other.node < entry.node:
             return entry, other
 
-        raise RuntimeError("This cannot happen: %s %s", entry.node, entry.tock)
+        raise RuntimeError("This cannot happen: %s %s" % (entry.node, entry.tock))
 
-    async def record_working(
+    async def record_working(  # pylint: disable=dangerous-default-value
         self, subsystem, *path, comment=None, data={}, force=False
     ):
         """This exception has been fixed.
-        
+
         Arguments:
           subsystem (str): The subsystem with the error.
           *path: the path to the no-longer-offending entry.
@@ -410,12 +451,11 @@ class ErrorRoot(ClientRoot):
             await rec.real_entry.add_comment(self.name, comment, data)
         return rec
 
-    async def record_error(
+    async def record_error(  # pylint: disable=dangerous-default-value
         self,
         subsystem,
         *path,
         exc=None,
-        reason=None,
         data={},
         severity=0,
         message=None,
@@ -423,7 +463,7 @@ class ErrorRoot(ClientRoot):
         comment: str = None
     ):
         """An exception has occurred for this subtype and path.
-        
+
         Arguments:
           subsystem (str): The subsystem with the error.
           *path: the path to the no-longer-offending entry.
@@ -447,21 +487,17 @@ class ErrorRoot(ClientRoot):
         rec.path = path
         rec.resolved = False
         rec.count += 1
-        if not hasattr(rec, 'first_seen'):
+        if not hasattr(rec, "first_seen"):
             rec.first_seen = time()
         rec.last_seen = time()
 
         try:
             await rec.save()
         except anyio.exceptions.ClosedResourceError:
-            return # owch, but can't be helped
+            return  # owch, but can't be helped
 
         await rec.real_entry.add_exc(
-            self.name,
-            exc=exc,
-            data=data,
-            comment=comment,
-            message=message,
+            self.name, exc=exc, data=data, comment=comment, message=message
         )
         return rec
 
@@ -480,7 +516,6 @@ class ErrorRoot(ClientRoot):
         except KeyError:
             pass
 
-
     def _push(self, entry):
         if entry.subsystem is None or entry.path is None:
             return
