@@ -2,7 +2,7 @@ import pytest
 import trio
 from time import time
 
-from .mock_serf import stdtest
+from .mock_mqtt import stdtest
 from .run import run
 from distkv.client import ServerError
 from distkv.util import PathLongener
@@ -16,7 +16,7 @@ logger = logging.getLogger(__name__)
 # (a) the autojump clock works as advertised
 # (b) we can use trio.
 @pytest.mark.trio
-async def test_00_trio_clock(autojump_clock):
+async def test_00_trio_clock(autojump_clock):  # pylint: disable=unused-argument
     assert trio.current_time() == 0
     t = time()
 
@@ -30,7 +30,7 @@ async def test_00_trio_clock(autojump_clock):
 
 
 @pytest.mark.trio
-async def test_00_runner(autojump_clock):
+async def test_00_runner(autojump_clock):  # pylint: disable=unused-argument
     with pytest.raises(AssertionError):
         await run("--doesnotexist")
     await run("--doesnotexist", expect_exit=2)
@@ -49,15 +49,15 @@ async def collect(i, path=()):
 
 
 @pytest.mark.trio
-async def test_01_basic(autojump_clock):
-    async with stdtest(args={"init": 123}) as st:
-        s, = st.s
+async def test_01_basic(autojump_clock):  # pylint: disable=unused-argument
+    async with stdtest(args={"init": 123}, tocks=50) as st:
         async with st.client() as c:
             assert (await c.get()).value == 123
 
             r = await c.set("foo", value="hello", nchain=3)
             r = await c.set("foo", "bar", value="baz", nchain=3)
             bart = r.tock
+            r = await c.set("foo", "baz", value="quux", nchain=3)
             r = await c.get()
             assert r.value == 123
             assert r.tock < await c.get_tock()
@@ -69,11 +69,26 @@ async def test_01_basic(autojump_clock):
                 {"path": (), "value": 123},
                 {"path": ("foo",), "value": "hello"},
                 {"path": ("foo", "bar"), "value": "baz"},
+                {"path": ("foo", "baz"), "value": "quux"},
             ]
+            r = await c.list()
+            assert r == (None, ".distkv", "foo")
+            r = await c.list("foo")
+            assert r == ("bar", "baz")
+            r = await c.list("foo", with_data=True)
+            assert r == dict(bar="baz", baz="quux")
+            r = await c.list("foo", "bar")
+            assert r == ()
+
             async with c._stream("get_tree", path=(), max_depth=2) as rr:
                 r = await collect(rr)
             assert r == exp
 
+            async with c._stream("get_tree", path=(), min_depth=1) as rr:
+                r = await collect(rr)
+            assert r == exp[1:]
+
+            exp.pop()
             exp.pop()
             async with c._stream("get_tree", path=(), iter=True, max_depth=1) as rr:
                 r = await collect(rr)
@@ -89,15 +104,20 @@ async def test_01_basic(autojump_clock):
             assert r.tock == bart
 
             r = await c._request(
-                "get_state", nodes=True, known=True, missing=True, remote_missing=True, present=True
+                "get_state",
+                nodes=True,
+                known=True,
+                missing=True,
+                remote_missing=True,
+                present=True,
             )
             del r["tock"]
             del r["seq"]
             assert r == {
                 "node": "test_0",
-                "nodes": {"test_0": 3},
+                "nodes": {"test_0": 4},
                 "known": {},
-                "present": {'test_0': ((1, 4),)},
+                "present": {"test_0": ((1, 5),)},
                 "missing": {},
                 "remote_missing": {},
             }
@@ -110,7 +130,7 @@ async def test_01_basic(autojump_clock):
 
             r = await c.set(value=1234, nchain=3)
             assert r.prev == 123
-            assert r.chain.tick == 4
+            assert r.chain.tick == 5
 
             # does not yet exist
             with pytest.raises(ServerError):
@@ -119,22 +139,27 @@ async def test_01_basic(autojump_clock):
             with pytest.raises(ServerError):
                 await c._request("get_value", node="test_0", tick=1)
             # works
-            assert (await c._request("get_value", node="test_0", tick=4)).value == 1234
+            assert (await c._request("get_value", node="test_0", tick=5)).value == 1234
 
             r = await c.set("foo", "bar", value="bazz")
             assert r.tock > bart
             bart = r.tock
 
             r = await c._request(
-                "get_state", nodes=True, known=True, missing=True, remote_missing=True, present=True
+                "get_state",
+                nodes=True,
+                known=True,
+                missing=True,
+                remote_missing=True,
+                present=True,
             )
             del r["tock"]
             del r["seq"]
             assert r == {
                 "node": "test_0",
-                "nodes": {"test_0": 5},
+                "nodes": {"test_0": 6},
                 "known": {"test_0": (1, 3)},
-                "present": {'test_0': (2, (4, 6),)},
+                "present": {"test_0": (2, (4, 7))},
                 "missing": {},
                 "remote_missing": {},
             }
@@ -151,11 +176,12 @@ async def test_01_basic(autojump_clock):
 
 
 @pytest.mark.trio
-async def test_02_cmd(autojump_clock):
-    async with stdtest(args={"init": 123}) as st:
-        s, = st.s
+async def test_02_cmd(autojump_clock):  # pylint: disable=unused-argument
+    async with stdtest(args={"init": 123}, tocks=50) as st:
         async with st.client() as c:
             assert (await c.get()).value == 123
+            s, = st.s
+            h = p = None  # pylint
             for h, p, *_ in s.ports:
                 if h[0] != ":":
                     break
@@ -177,7 +203,12 @@ async def test_02_cmd(autojump_clock):
             assert r.stdout == "'baz'\n"
 
             r = await c._request(
-                "get_state", nodes=True, known=True, missing=True, remote_missing=True, present=True
+                "get_state",
+                nodes=True,
+                known=True,
+                missing=True,
+                remote_missing=True,
+                present=True,
             )
             del r["tock"]
             del r["seq"]
@@ -185,7 +216,7 @@ async def test_02_cmd(autojump_clock):
                 "node": "test_0",
                 "nodes": {"test_0": 3},
                 "known": {},
-                'present': {'test_0': ((1, 4),)},
+                "present": {"test_0": ((1, 4),)},
                 "missing": {},
                 "remote_missing": {},
             }
@@ -210,7 +241,12 @@ async def test_02_cmd(autojump_clock):
             assert (await c._request("get_value", node="test_0", tick=4)).value == 1234
 
             r = await c._request(
-                "get_state", nodes=True, known=True, missing=True, remote_missing=True, present=True
+                "get_state",
+                nodes=True,
+                known=True,
+                missing=True,
+                remote_missing=True,
+                present=True,
             )
             del r["tock"]
             del r["seq"]
@@ -218,7 +254,7 @@ async def test_02_cmd(autojump_clock):
                 "node": "test_0",
                 "nodes": {"test_0": 4},
                 "known": {"test_0": (1,)},
-                'present': {'test_0': ((2, 5),)},
+                "present": {"test_0": ((2, 5),)},
                 "missing": {},
                 "remote_missing": {},
             }
@@ -227,14 +263,18 @@ async def test_02_cmd(autojump_clock):
 
 
 @pytest.mark.trio
-async def test_03_three(autojump_clock):
+async def test_03_three(autojump_clock):  # pylint: disable=unused-argument
     async with stdtest(test_1={"init": 125}, n=2, tocks=30) as st:
-        s, si = st.s
         async with st.client(1) as ci:
             assert (await ci._request("get_value", path=())).value == 125
 
             r = await ci._request(
-                "get_state", nodes=True, known=True, missing=True, remote_missing=True, present=True
+                "get_state",
+                nodes=True,
+                known=True,
+                missing=True,
+                remote_missing=True,
+                present=True,
             )
             del r["tock"]
             del r["seq"]
@@ -340,6 +380,7 @@ async def test_03_three(autojump_clock):
                 assert r.chain.prev.node == "test_0"
                 assert r.chain.prev.tick == 1
                 assert r.chain.prev.prev is None
+                await trio.sleep(1)
 
                 with pytest.raises(ServerError):
                     await c._request("get_value", node="test_1", tick=1)
@@ -361,21 +402,26 @@ async def test_03_three(autojump_clock):
                 assert r == {
                     "node": "test_0",
                     "nodes": {"test_0": 1, "test_1": 2},
-                    'known': {'test_1': (1,)},
+                    "known": {"test_1": (1,)},
                     "present": {"test_0": (1,), "test_1": (2,)},
                     "missing": {},
                     "remote_missing": {},
                 }
 
             r = await ci._request(
-                "get_state", nodes=True, known=True, missing=True, remote_missing=True, present=True
+                "get_state",
+                nodes=True,
+                known=True,
+                missing=True,
+                remote_missing=True,
+                present=True,
             )
             del r["tock"]
             del r["seq"]
             assert r == {
                 "node": "test_1",
                 "nodes": {"test_0": 1, "test_1": 2},
-                'known': {'test_1': (1,)},
+                "known": {"test_1": (1,)},
                 "present": {"test_0": (1,), "test_1": (2,)},
                 "missing": {},
                 "remote_missing": {},
