@@ -3,13 +3,9 @@ import trio
 import anyio
 import time
 
-from .mock_serf import stdtest
+from .mock_mqtt import stdtest
 
 from .run import run
-from functools import partial
-
-from distkv.client import ServerError
-from distkv.util import PathLongener
 
 from distkv.code import CodeRoot
 from distkv.runner import AllRunnerRoot
@@ -20,11 +16,10 @@ logger = logging.getLogger(__name__)
 
 
 @pytest.mark.trio
-async def test_83_run(autojump_clock):
-    from distkv import runner
-
-    async with stdtest(args={"init": 123}) as st:
+async def test_83_run(autojump_clock):  # pylint: disable=unused-argument
+    async with stdtest(args={"init": 123}, tocks=50) as st:
         s, = st.s
+        h = p = None  # pylint
         for h, p, *_ in s.ports:
             if h[0] != ":":
                 break
@@ -47,7 +42,7 @@ async def test_83_run(autojump_clock):
             )
             ru = r.follow("foo", "test", create=True)
             ru.code = ("forty", "two")
-            await ru.run_at(time.time()+1)
+            await ru.run_at(time.time() + 1)
             logger.info("Start sleep")
             with trio.fail_after(60):
                 await c._test_evt.wait()
