@@ -1,6 +1,6 @@
 import pytest
 
-from .mock_serf import stdtest
+from .mock_mqtt import stdtest
 
 import logging
 
@@ -8,7 +8,7 @@ logger = logging.getLogger(__name__)
 
 
 @pytest.mark.trio
-async def test_51_dh(autojump_clock):
+async def test_51_dh(autojump_clock):  # pylint: disable=unused-argument
     async with stdtest(args={"init": 123}) as st:
         s, = st.s
         async with st.client() as c:
