@@ -1,6 +1,6 @@
 import pytest
 
-from .mock_serf import stdtest
+from .mock_mqtt import stdtest
 
 import logging
 
@@ -8,9 +8,8 @@ logger = logging.getLogger(__name__)
 
 
 @pytest.mark.trio
-async def test_61_basic(autojump_clock):
+async def test_61_basic(autojump_clock):  # pylint: disable=unused-argument
     async with stdtest(args={"init": 123}, tocks=30) as st:
-        s, = st.s
         async with st.client() as c:
             async with c.mirror("foo", need_wait=True) as m:
                 assert (await c.get()).value == 123
